traits-enaml
============

Traits-Enaml is an extension library to facilitate interoperation of `Enaml
0.8.x` with `Traits` and allow a programmer to drive enaml views using
traits models, enable/chaco components and mayavi 3D scenes.

References
==========

Traits https://github.com/enthought/traits
Enable https://github.com/enthought/enable
Mayavi https://github.com/enthought/mayavi
Enaml  https://github.com/nucleic/enaml

